Cursor

Struct Cursor 

pub struct Cursor<'id, 's, 'a, T: Flat, Root: Flat, B: Buf> { /* private fields */ }
Chainable cursor over a Session.

Provides a fluent API for navigating and mutating a region. Each method consumes self (by move), preventing borrow conflicts. For complex navigation patterns or batch operations, use Session methods directly.

use nearest::{Flat, Near, Region, near};

#[derive(Flat, Debug)]
struct Outer { inner: Near<Inner> }

#[derive(Flat, Debug, Clone, Copy)]
struct Inner { value: u32 }

let mut region = Region::new(Outer::make(near(Inner { value: 1 })));
assert_eq!(region.inner.get().value, 1);

region.session(|s| {
  s.cursor()
    .at(|root| &root.inner)       // navigate to inner Near<Inner>
    .follow()                      // dereference the Near pointer
    .set(Inner { value: 42 });     // overwrite
});

assert_eq!(region.inner.get().value, 42);

Implementations

Source

impl<'id, 's, 'a, T: Flat, Root: Flat, B: Buf> Cursor<'id, 's, 'a, T, Root, B>

pub fn at<U: Flat>( self, f: impl FnOnce(&T) -> &U, ) -> Cursor<'id, 's, 'a, U, Root, B>

Navigate to a sub-field.

pub fn get(&self) -> &T

Read the value at this cursor’s position.

pub const fn pin(self) -> Ref<'id, T>

Extract the Ref at this cursor’s position.

Source

impl<T: Flat + Copy, Root: Flat, B: Buf> Cursor<'_, '_, '_, T, Root, B>

pub fn set(self, val: T)

Overwrite the value at this cursor’s position.

Source

impl<T: Flat, Root: Flat, B: Buf> Cursor<'_, '_, '_, T, Root, B>

pub fn write_with(self, builder: impl Emit<T>)

Overwrite the value at this cursor’s position using a builder.

Source

impl<'id, 's, 'a, U: Flat, Root: Flat, B: Buf> Cursor<'id, 's, 'a, Near<U>, Root, B>

pub fn splice(self, builder: impl Emit<U>)

Replace the target of this Near<U> pointer with freshly emitted data.

pub fn follow(self) -> Cursor<'id, 's, 'a, U, Root, B>

Follow the Near pointer, returning a cursor at the target.

Source

impl<U: Flat, Root: Flat, B: Buf> Cursor<'_, '_, '_, NearList<U>, Root, B>

pub fn splice_list<E: Emit<U>, I>(self, items: I)
where I: IntoIterator<Item = E>, I::IntoIter: ExactSizeIterator,

Replace the elements of this NearList<U>.

pub fn filter_list(self, pred: impl FnMut(&U) -> bool)

Remove elements that do not satisfy a predicate.